@@ -4,10 +4,10 @@ use warnings;
 
 package Hash::Ordered;
 # ABSTRACT: A compact, pure-Perl ordered hash class
-our $VERSION = '0.002'; # VERSION
+
+our $VERSION = '0.004';
 
 use Carp ();
-use List::Util 1.09 ();
 
 use constant {
     _DATA => 0,
@@ -151,13 +151,34 @@ sub delete {
     if ( exists $self->[_DATA]{$key} ) {
         # XXX could put an index on this later if linear search is too slow
         my $r = $self->[_KEYS];
-        my $i = List::Util::first { $r->[$_] eq $key } 0 .. $#$r;
+        my $i;
+        for ( 0 .. $#$r ) {
+            if ( $r->[$_] eq $key ) { $i = $_; last; }
+        }
         splice @$r, $i, 1;
         return delete $self->[_DATA]{$key};
     }
     return undef; ## no critic
 }
 
+#pod =method clear
+#pod
+#pod     $oh->clear;
+#pod
+#pod Removes all key-value pairs from the hash.  Returns undef in scalar context
+#pod or an empty list in list context.
+#pod
+#pod Added in version 0.003.
+#pod
+#pod =cut
+
+sub clear {
+    my ($self) = @_;
+    %{ $self->[_DATA] } = ();
+    @{ $self->[_KEYS] } = ();
+    return;
+}
+
 #pod =method push
 #pod
 #pod     $oh->push( one => 1, two => 2);
@@ -176,9 +197,11 @@ sub push {
         my ( $k, $v ) = splice( @pairs, 0, 2 );
         if ( exists $self->[_DATA]{$k} ) {
             # splice out key
-            # XXX could put an index on this later if linear search is too slow
             my $r = $self->[_KEYS];
-            my $i = List::Util::first { $r->[$_] eq $k } 0 .. $#$r;
+            my $i;
+            for ( 0 .. $#$r ) {
+                if ( $r->[$_] eq $k ) { $i = $_; last; }
+            }
             splice @$r, $i, 1;
         }
         push @{ $self->[_KEYS] }, $k;
@@ -219,9 +242,11 @@ sub unshift {
         my ( $k, $v ) = splice( @pairs, -2, 2 );
         if ( exists $self->[_DATA]{$k} ) {
             # splice out key
-            # XXX could put an index on this later if linear search is too slow
             my $r = $self->[_KEYS];
-            my $i = List::Util::first { $r->[$_] eq $k } 0 .. $#$r;
+            my $i;
+            for ( 0 .. $#$r ) {
+                if ( $r->[$_] eq $k ) { $i = $_; last; }
+            }
             splice @$r, $i, 1;
         }
         unshift @{ $self->[_KEYS] }, $k;
@@ -331,7 +356,7 @@ Hash::Ordered - A compact, pure-Perl ordered hash class
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -434,6 +459,15 @@ Test if some key exists in the hash (without creating it).
 Removes a key-value pair from the hash and returns the value.  This
 is expensive, as the ordered list of keys has to be updated.
 
+=head2 clear
+
+    $oh->clear;
+
+Removes all key-value pairs from the hash.  Returns undef in scalar context
+or an empty list in list context.
+
+Added in version 0.003.
+
 =head2 push
 
     $oh->push( one => 1, two => 2);
@@ -640,6 +674,22 @@ L<https://github.com/dagolden/Hash-Ordered>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Benct Philip Jonsson Mario Roy
+
+=over 4
+
+=item *
+
+Benct Philip Jonsson <bpjonsson@gmail.com>
+
+=item *
+
+Mario Roy <marioeroy@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by David Golden.
